=================================
Using Python to command FireWorks
=================================

In addition to the command line, FireWorks can be controlled using Python code.

This tutorial will be further developed in the future. For now, please take a look at the examples provided in the file ``python_examples.py``, which can be found in the ``python`` tutorials directory::

    cd <INSTALL_DIR>/fw_tutorials/python
    cat python_examples.py
    python python_examples.py

A few more examples can be found by browsing our unit tests::

    cd <INSTALL_DIR>/tests
    cat mongo_tests.py

